import { Document as RichTextDocument } from '@contentful/rich-text-types';
import { Asset } from './asset';
import { ContentfulCollection } from './collection';
import { ContentTypeLink, EntryLink } from './link';
import { LocaleCode } from './locale';
import { Metadata } from './metadata';
import { FieldsType } from './query/util';
import { EntitySys } from './sys';
export interface EntrySys extends EntitySys {
    contentType: {
        sys: ContentTypeLink;
    };
}
export declare namespace EntryFields {
    type Symbol = string;
    type Text = string;
    type Integer = number;
    type Number = number;
    type Date = `${number}-${number}-${number}T${number}:${number}:${number}Z`;
    type Boolean = boolean;
    type Location = {
        lat: string;
        lon: string;
    };
    type Link<T> = Asset | Entry<T>;
    type Array<T = any> = symbol[] | Entry<T>[] | Asset[];
    type Object<T extends Record<string, any> = Record<string, unknown>> = T;
    type RichText = RichTextDocument;
}
export declare type BasicEntryField = EntryFields.Symbol | EntryFields.Text | EntryFields.Integer | EntryFields.Number | EntryFields.Date | EntryFields.Boolean | EntryFields.Location | EntryFields.RichText | EntryFields.Object;
/**
 * @category Entities
 */
export interface Entry<T> {
    sys: EntrySys;
    metadata: Metadata;
    fields: T;
}
export interface EntryWithAllLocalesAndWithoutLinkResolution<Fields extends FieldsType, Locales extends LocaleCode> {
    sys: EntrySys;
    metadata: Metadata;
    fields: {
        [FieldName in keyof Fields]: {
            [LocaleName in Locales]?: Fields[FieldName] extends EntryFields.Link<any> ? EntryLink : Fields[FieldName] extends EntryFields.Link<any>[] ? EntryLink[] : Fields[FieldName];
        };
    };
}
export declare type EntryWithLinkResolutionAndWithUnresolvableLinks<Fields extends FieldsType> = {
    sys: EntrySys;
    metadata: Metadata;
    fields: {
        [FieldName in keyof Fields]: Fields[FieldName] extends EntryFields.Link<infer LinkedEntryFields> ? EntryWithLinkResolutionAndWithUnresolvableLinks<LinkedEntryFields> | EntryLink : Fields[FieldName] extends EntryFields.Link<infer LinkedEntryFields>[] ? (EntryWithLinkResolutionAndWithUnresolvableLinks<LinkedEntryFields> | EntryLink)[] : Fields[FieldName];
    };
};
export declare type EntryWithAllLocalesAndWithLinkResolutionAndWithUnresolvableLinks<Fields extends FieldsType, Locales extends LocaleCode> = {
    sys: EntrySys;
    metadata: Metadata;
    fields: {
        [FieldName in keyof Fields]: {
            [LocaleName in Locales]?: Fields[FieldName] extends EntryFields.Link<infer LinkedEntryFields> ? EntryWithAllLocalesAndWithLinkResolutionAndWithUnresolvableLinks<LinkedEntryFields, Locales> | undefined : Fields[FieldName] extends Array<EntryFields.Link<infer LinkedEntryFields>> ? EntryWithAllLocalesAndWithLinkResolutionAndWithUnresolvableLinks<LinkedEntryFields, Locales>[] | undefined : Fields[FieldName];
        };
    };
};
export declare type EntryWithLinkResolutionAndWithoutUnresolvableLinks<Fields extends FieldsType> = {
    sys: EntrySys;
    metadata: Metadata;
    fields: {
        [FieldName in keyof Fields]: Fields[FieldName] extends EntryFields.Link<infer LinkedEntryFields> ? EntryWithLinkResolutionAndWithoutUnresolvableLinks<LinkedEntryFields> | undefined : Fields[FieldName] extends EntryFields.Link<infer LinkedEntryFields>[] ? EntryWithLinkResolutionAndWithoutUnresolvableLinks<LinkedEntryFields>[] | undefined : Fields[FieldName];
    };
};
export declare type EntryWithAllLocalesAndWithLinkResolutionAndWithoutUnresolvableLinks<Fields extends FieldsType, Locales extends LocaleCode> = {
    sys: EntrySys;
    metadata: Metadata;
    fields: {
        [FieldName in keyof Fields]: {
            [LocaleName in Locales]?: Fields[FieldName] extends EntryFields.Link<infer LinkedEntryFields> ? EntryWithAllLocalesAndWithLinkResolutionAndWithoutUnresolvableLinks<LinkedEntryFields, Locales> | undefined : Fields[FieldName] extends EntryFields.Link<infer LinkedEntryFields>[] ? EntryWithAllLocalesAndWithLinkResolutionAndWithoutUnresolvableLinks<LinkedEntryFields, Locales>[] | undefined : Fields[FieldName];
        };
    };
};
export interface AbstractEntryCollection<TEntry> extends ContentfulCollection<TEntry> {
    errors?: Array<any>;
    includes?: {
        Entry?: any[];
        Asset?: any[];
    };
}
export declare type EntryCollection<T> = AbstractEntryCollection<Entry<T>>;
export declare type EntryWithoutLinkResolution<T> = Entry<T>;
export declare type EntryCollectionWithoutLinkResolution<T> = EntryCollection<T>;
export declare type EntryCollectionWithLinkResolutionAndWithUnresolvableLinks<T> = AbstractEntryCollection<EntryWithLinkResolutionAndWithUnresolvableLinks<T>>;
export declare type EntryCollectionWithAllLocalesAndWithoutLinkResolution<Fields, Locales extends LocaleCode> = AbstractEntryCollection<EntryWithAllLocalesAndWithoutLinkResolution<Fields, Locales>>;
export declare type EntryCollectionWithAllLocalesAndWithLinkResolutionAndWithUnresolvableLinks<Fields, Locales extends LocaleCode> = AbstractEntryCollection<EntryWithAllLocalesAndWithLinkResolutionAndWithUnresolvableLinks<Fields, Locales>>;
export declare type EntryCollectionWithLinkResolutionAndWithoutUnresolvableLinks<Fields> = AbstractEntryCollection<EntryWithLinkResolutionAndWithoutUnresolvableLinks<Fields>>;
export declare type EntryCollectionWithAllLocalesAndWithLinkResolutionAndWithoutUnresolvableLinks<Fields, Locales extends LocaleCode> = AbstractEntryCollection<EntryWithAllLocalesAndWithLinkResolutionAndWithoutUnresolvableLinks<Fields, Locales>>;
