import { ConditionalPick } from 'type-fest';
import { EntryFields } from '../entry';
import { NonEmpty } from './util';
declare type Types = EntryFields.Location;
export declare type ProximitySearchFilterInput = [number, number] | undefined;
export declare type BoundingBoxSearchFilterInput = [number, number, number, number] | undefined;
export declare type BoundingCircleSearchFilterInput = [number, number, number] | undefined;
declare type BaseLocationFilter<Fields, SupportedTypes, ValueType, Prefix extends string, QueryFilter extends string = ''> = NonEmpty<NonNullable<{
    [FieldName in keyof ConditionalPick<Fields, SupportedTypes> as `${Prefix}.${string & FieldName}[${QueryFilter}]`]?: ValueType;
}>>;
/**
 * @desc near - location proximity search
 * @see [Documentation]{@link https://www.contentful.com/developers/docs/references/content-delivery-api/#/reference/search-parameters/location-proximity-search}
 */
export declare type ProximitySearchFilter<Fields, Prefix extends string> = BaseLocationFilter<Fields, Types, ProximitySearchFilterInput, Prefix, 'near'>;
/**
 * @desc within - location in a bounding rectangle
 * @see [Documentation]{@link https://www.contentful.com/developers/docs/references/content-delivery-api/#/reference/search-parameters/locations-in-a-bounding-object}
 */
declare type BoundingBoxSearchFilter<Fields, Prefix extends string> = BaseLocationFilter<Fields, Types, BoundingBoxSearchFilterInput, Prefix, 'within'>;
/**
 * @desc within - location in a bounding circle
 * @see [Documentation]{@link https://www.contentful.com/developers/docs/references/content-delivery-api/#/reference/search-parameters/locations-in-a-bounding-object}
 */
declare type BoundingCircleSearchFilter<Fields, Prefix extends string> = BaseLocationFilter<Fields, Types, BoundingCircleSearchFilterInput, Prefix, 'within'>;
/**
 * @desc location search
 * @see [proximity]{@link ProximitySearchFilter}
 * @see [bounding rectangle]{@link BoundingBoxSearchFilter}
 * @see [bounding circle]{@link BoundingCircleSearchFilter}
 */
export declare type LocationSearchFilters<Fields, Prefix extends string> = ProximitySearchFilter<Fields, Prefix> | BoundingBoxSearchFilter<Fields, Prefix> | BoundingCircleSearchFilter<Fields, Prefix>;
export {};
